@@ -1,5 +1,5 @@
 /*
- * $Id: output.c,v 1.80.4.7 2001/11/29 10:14:54 knok Exp $
+ * $Id: output.c,v 1.80.4.12 2001/12/21 08:44:40 knok Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -86,7 +86,7 @@ char contenttype[BUFSIZE] = "text/html";
  *
  */
 
-static void emprint ( char *str, int entity_encode );
+static void emprint( char *s, int entity_encode );
 static void fputs_without_html_tag ( const char *str, FILE *fp );
 static char *load_nmz_result(const char *basedir);
 static void print_hitnum_each ( struct nmz_hitnumlist *hn );
@@ -309,15 +309,15 @@ load_nmz_result(const char *basedir)
     char fname[BUFSIZE], lang_suffix[BUFSIZE], *buf;
 
     nmz_pathcat(basedir, NMZ.result);
-    strcpy(fname, NMZ.result);
-    strcat(fname, ".");
-    strcat(fname, get_templatesuffix());  /* usually "normal" */
+    strncpy(fname, NMZ.result, BUFSIZE - 1);
+    strncat(fname, ".", BUFSIZE - strlen(fname) - 1);
+    strncat(fname, get_templatesuffix(), BUFSIZE - strlen(fname) - 1);  /* usually "normal" */
 
     if (nmz_choose_msgfile_suffix(fname, lang_suffix) != SUCCESS) {
 	nmz_warn_printf("%s: %s", fname, strerror(errno));
 	return NULL;
     } 
-    strcat(fname, lang_suffix);
+    strncat(fname, lang_suffix, BUFSIZE - strlen(fname) - 1);
 
     /* buf is allocated in nmz_readfile. */
     buf = nmz_readfile(fname); 
@@ -471,16 +471,12 @@ print_query(const char * qs, int w)
 	    for (qs += strlen("whence="); isdigit(*qs); qs++);
 	} else {
 	    /* '"' is converted to entities "&quot;" */
-	    if (*qs == '"') {
-		fputs("&quot;", stdout);
-	    } else {
-		fputc(*qs, stdout);
-	    }
+	    putc_entitize(*qs);
 	    qs++;
 	}
     }
     if (foo == 0) {
-	printf("&whence=%d", w);
+	printf("&amp;whence=%d", w);
     }
 }
 
@@ -587,7 +583,7 @@ print_hitnum_all_idx(void)
 			    + strlen(nmz_get_defaultidx()) + 1;
 		    }
 		    printf("<li><strong>");
-		    emprint(idxname, 1);
+		    puts_entitize(idxname);
 		    printf("</strong>: ");
 		} else {
 		    printf("(%s)", nmz_get_idxname(idxid));
@@ -633,8 +629,8 @@ print_msgfile(const char *fname) {
     if (nmz_choose_msgfile_suffix(fname, suffix) == SUCCESS) {
 	char *buf;
 
-	strcpy(tmpfname, fname);
-	strcat(tmpfname, suffix);
+	strncpy(tmpfname, fname, BUFSIZE - 1);
+	strncat(tmpfname, suffix, BUFSIZE - strlen(tmpfname) - 1);
 
 	buf = nmz_readfile(tmpfname); /* buf is allocated in nmz_readfile. */
 	if (buf == NULL) {
@@ -679,7 +675,7 @@ print_errmsg(int errid)
 {
     char *errmsg = nmz_strerror(errid);
     char buf[BUFSIZE];
-    sprintf(buf, _("	<h2>Error!</h2>\n<p>%s</p>\n"), errmsg);
+    snprintf(buf, BUFSIZE - 1, _("	<h2>Error!</h2>\n<p>%s</p>\n"), errmsg);
     html_print(buf);
 }
 
@@ -790,11 +786,41 @@ print_default_page (void) {
     }
 }
 
+/*
+ * output string as non-html (replace special characters by entities)
+ */
+void
+puts_entitize(const char *str)
+{
+    const char *p = str;
+    for (; *p != 0; p++) {
+	putc_entitize(*p);
+    }
+}
+
+void
+putc_entitize(int c)
+{
+	if (c == '<') {
+	    fputs("&lt;", stdout);
+	} else if (c == '>') {
+	    fputs("&gt;", stdout);
+	} else if (c == '&') {
+	    fputs("&amp;", stdout);
+	} else if (c == '"') {
+	    fputs("&quot;", stdout);
+	} else if (c == '\'') {
+	    fputs("&apos;", stdout);
+	} else {
+	    fputc(c, stdout);
+	}
+}
+
 void 
 set_emphasis_tags(const char *start_tag, const char *end_tag)
 {
-    strncpy(emphasis_start_tag, start_tag, BUFSIZE);
-    strncpy(emphasis_end_tag,   end_tag, BUFSIZE);
+    strncpy(emphasis_start_tag, start_tag, BUFSIZE - 1);
+    strncpy(emphasis_end_tag,   end_tag, BUFSIZE - 1);
 }
 
 char *
@@ -812,7 +838,7 @@ get_emphasis_tag_end(void)
 void
 set_contenttype(const char *str)
 {
-    strncpy(contenttype, str, BUFSIZE);
+    strncpy(contenttype, str, BUFSIZE - 1);
 }
 
 void 
